# CSDA data
This folder contains files describing csda range

**Origin:** This data comes from the the NIST database (see [Ref. 1](http://www.nist.gov/pml/data/xraycoef/))

**How obtained:** A included Mathematica script was used to fetch the data

**File list:**
- [74.csv](74.csv)
- [GetCSDA.nb](getcsda.nb)

## 74.csv
-First row: energy in keV

-Second row: csda range in cm (assuming density=19.25g/cm^3)

## GetCSDA.nb
The Mathematica script used to fetch this data.
